SerializedRegistry

Struct SerializedRegistry 

pub struct SerializedRegistry<N, E> {
    pub nodes: SlotMap<NodeId, SerializedInnerData<N, E>>,
}
A serializable representation of a Registry object.

You typically do not want to use this type directly, as registries shouldn’t be serialised on their own. (They only keep weak references to nodes).

Fields

nodes: SlotMap<NodeId, SerializedInnerData<N, E>>

The nodes in the registry and their serialized data.

Implementations

Source

impl<N: Clone, E: Clone> SerializedRegistry<N, E>

pub fn map_nodes<M>(&self, f: impl FnMut(N) -> M) -> SerializedRegistry<M, E>

Map the value of the nodes in the registry.